pyjabber.plugins.xep\_0004 package
==================================

Submodules
----------

pyjabber.plugins.xep\_0004.field module
---------------------------------------

.. automodule:: pyjabber.plugins.xep_0004.field
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.plugins.xep\_0004.xep\_0004 module
-------------------------------------------

.. automodule:: pyjabber.plugins.xep_0004.xep_0004
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.plugins.xep_0004
   :members:
   :undoc-members:
   :show-inheritance:
